==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDetailDescription } from "./WebColumnVisibilityChangingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata, _super);
    function WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebColumnVisibilityChangingEventArgsDetail", function () { return new WebColumnVisibilityChangingEventArgsDetailDescription(); });
        a.ac("WebColumnVisibilityChangingEventArgsDetail", WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescription } from "./WebColumnVisibilityChangingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata, _super);
    function WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Column", "Unknown");
        a.item("NewValue", "Boolean");
        a.item("Cancel", "Boolean");
    };
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebColumnVisibilityChangingEventArgsDetail", function () { return new WebColumnVisibilityChangingEventArgsDetailDescription(); });
        a.ad("WebColumnVisibilityChangingEventArgsDetail", WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata };
